@@ -939,6 +939,7 @@ another_version_retry:
 	 * function instead.
 	 */
 	CC_send_settings(self);
+	CC_clear_error(self);			/* clear any error */
 	CC_lookup_lo(self);			/* a hack to get the oid of
 						   our large object oid type */
 
@@ -1165,7 +1166,14 @@ void	CC_on_abort(ConnectionClass *conn, UDWORD opt)
 		}
 	}
 	if (0 != (opt & CONN_DEAD))
+	{
 		conn->status = CONN_DOWN;
+		if (conn->sock)
+		{
+			SOCK_Destructor(conn->sock);
+			conn->sock = NULL;
+		}
+	}
 	conn->result_uncommitted = 0;
 }
 
@@ -1209,6 +1217,13 @@ CC_send_query(ConnectionClass *self, char *query, QueryInfo *qi, UDWORD flag)
 	mylog("send_query(): conn=%u, query='%s'\n", self, query);
 	qlog("conn=%u, query='%s'\n", self, query);
 
+	if (!self->sock)
+	{
+		CC_set_error(self, CONNECTION_COULD_NOT_SEND, "Could not send Query(connection dead)");
+		CC_on_abort(self, NO_TRANS);
+		return NULL;
+	}
+
 	/* Indicate that we are sending a query to the backend */
 	maxlen = CC_get_max_query_len(self);
 	if (maxlen > 0 && maxlen < (int) strlen(query) + 1)
@@ -1606,6 +1621,13 @@ CC_send_function(ConnectionClass *self, int fnid, void *result_buf, int *actual_
 
 	mylog("send_function(): conn=%u, fnid=%d, result_is_int=%d, nargs=%d\n", self, fnid, result_is_int, nargs);
 
+	if (!self->sock)
+	{
+		CC_set_error(self, CONNECTION_COULD_NOT_SEND, "Could not send function(connection dead)");
+		CC_on_abort(self, NO_TRANS);
+		return FALSE;
+	}
+
 	if (SOCK_get_errcode(sock) != 0)
 	{
 		CC_set_error(self, CONNECTION_COULD_NOT_SEND, "Could not send function to backend");
@@ -1754,6 +1776,9 @@ CC_send_settings(ConnectionClass *self)
 	char		status = TRUE;
 	char	   *cs,
 			   *ptr;
+#ifdef	HAVE_STRTOK_R
+	char	*last;
+#endif /* HAVE_STRTOK_R */
 	static char *func = "CC_send_settings";
 
 
@@ -1804,7 +1829,11 @@ CC_send_settings(ConnectionClass *self)
 	if (ci->drivers.conn_settings[0] != '\0')
 	{
 		cs = strdup(ci->drivers.conn_settings);
+#ifdef	HAVE_STRTOK_R
+		ptr = strtok_r(cs, ";", &last);
+#else
 		ptr = strtok(cs, ";");
+#endif /* HAVE_STRTOK_R */
 		while (ptr)
 		{
 			result = PGAPI_ExecDirect(hstmt, ptr, SQL_NTS);
@@ -1813,7 +1842,11 @@ CC_send_settings(ConnectionClass *self)
 
 			mylog("%s: result %d, status %d from '%s'\n", func, result, status, ptr);
 
+#ifdef	HAVE_STRTOK_R
+			ptr = strtok_r(NULL, ";", &last);
+#else
 			ptr = strtok(NULL, ";");
+#endif /* HAVE_STRTOK_R */
 		}
 
 		free(cs);
@@ -1823,7 +1856,11 @@ CC_send_settings(ConnectionClass *self)
 	if (ci->conn_settings[0] != '\0')
 	{
 		cs = strdup(ci->conn_settings);
+#ifdef	HAVE_STRTOK_R
+		ptr = strtok_r(cs, ";", &last);
+#else
 		ptr = strtok(cs, ";");
+#endif /* HAVE_STRTOK_R */
 		while (ptr)
 		{
 			result = PGAPI_ExecDirect(hstmt, ptr, SQL_NTS);
@@ -1832,7 +1869,11 @@ CC_send_settings(ConnectionClass *self)
 
 			mylog("%s: result %d, status %d from '%s'\n", func, result, status, ptr);
 
+#ifdef	HAVE_STRTOK_R
+			ptr = strtok_r(NULL, ";", &last);
+#else
 			ptr = strtok(NULL, ";");
+#endif /* HAVE_STRTOK_R */
 		}
 
 		free(cs);
