@@ -246,7 +246,11 @@ timestamp2stime(const char *str, SIMPLE_TIME *st, BOOL *bZone, int *zone)
 		if (timediff == 0)		/* the same time zone */
 			return TRUE;
 		time0 -= timediff;
+#ifdef	HAVE_LOCALTIME_R
+		if (time0 >= 0 && (tm2 = localtime_r(&time0, &tm)) != NULL)
+#else
 		if (time0 >= 0 && (tm2 = localtime(&time0)) != NULL)
+#endif /* HAVE_LOCALTIME_R */
 		{
 			st->y = tm2->tm_year + 1900;
 			st->m = tm2->tm_mon + 1;
@@ -346,6 +350,9 @@ copy_and_convert_field(StatementClass *stmt, Int4 field_type, void *value, Int2
 	SIMPLE_TIME st;
 	time_t		t = time(NULL);
 	struct tm  *tim;
+#ifdef	HAVE_LOCALTIME_R
+	struct tm  tm;
+#endif /* HAVE_LOCALTIME_R */
 	int			pcbValueOffset,
 				rgbValueOffset;
 	char	   *rgbValueBindRow;
@@ -402,7 +409,11 @@ copy_and_convert_field(StatementClass *stmt, Int4 field_type, void *value, Int2
 	memset(&st, 0, sizeof(SIMPLE_TIME));
 
 	/* Initialize current date */
+#ifdef	HAVE_LOCALTIME_R
+	tim = localtime_r(&t, &tm);
+#else
 	tim = localtime(&t);
+#endif /* HAVE_LOCALTIME_R */
 	st.m = tim->tm_mon + 1;
 	st.d = tim->tm_mday;
 	st.y = tim->tm_year + 1900;
@@ -504,7 +515,11 @@ copy_and_convert_field(StatementClass *stmt, Int4 field_type, void *value, Int2
 				 * like the epoch
 				 */
 				t = 0;
+#ifdef	HAVE_LOCALTIME_R
+				tim = localtime_r(&t, &tm);
+#else
 				tim = localtime(&t);
+#endif /* HAVE_LOCALTIME_R */
 				st.m = tim->tm_mon + 1;
 				st.d = tim->tm_mday;
 				st.y = tim->tm_year + 1900;
@@ -1696,7 +1711,8 @@ copy_statement_with_parameters(StatementClass *stmt)
 		if (stmt->parse_status == STMT_PARSE_FATAL)
 		{
 			stmt->options.scroll_concurrency = SQL_CONCUR_READ_ONLY;
-			return SQL_ERROR;
+			if (stmt->options.cursor_type == SQL_CURSOR_KEYSET_DRIVEN)
+				stmt->options.cursor_type = SQL_CURSOR_STATIC;
 		}
 		else if (!stmt->updatable)
 		{
@@ -2176,6 +2192,9 @@ ResolveOneParam(QueryBuild *qb)
 	SIMPLE_TIME	st;
 	time_t		t;
 	struct tm	*tim;
+#ifdef	HAVE_LOCALTIME_R
+	struct tm	tm;
+#endif /* HAVE_LOCALTIME_R */
 	SDWORD		used;
 	char		*buffer, *buf, *allocbuf;
 	Oid		lobj_oid;
@@ -2278,7 +2297,11 @@ ResolveOneParam(QueryBuild *qb)
 	cbuf[0] = '\0';
 	memset(&st, 0, sizeof(st));
 	t = time(NULL);
+#ifdef	HAVE_LOCALTIME_R
+	tim = localtime_r(&t, &tm);
+#else
 	tim = localtime(&t);
+#endif /* HAVE_LOCALTIME_R */
 	st.m = tim->tm_mon + 1;
 	st.d = tim->tm_mday;
 	st.y = tim->tm_year + 1900;
@@ -2781,7 +2804,7 @@ convert_escape(QueryParse *qp, QueryBuild *qb)
 {
 	static const char *func = "convert_escape";
 	RETCODE	retval = SQL_SUCCESS;
-	char		buf[1024], key[65];
+	char		buf[1024], buf_small[128], key[65];
 	unsigned char	ucv;
 	UInt4		prtlen;
  
@@ -2837,25 +2860,25 @@ convert_escape(QueryParse *qp, QueryBuild *qb)
 	if (strcmp(key, "d") == 0)
 	{
 		/* Literal; return the escape part adding type cast */
-		F_ExtractOldTo(qp, buf, '}', sizeof(buf));
-		prtlen = snprintf(buf, sizeof(buf), "%s::date ", buf);
+		F_ExtractOldTo(qp, buf_small, '}', sizeof(buf_small));
+		prtlen = snprintf(buf, sizeof(buf), "%s::date ", buf_small);
 		CVT_APPEND_DATA(qb, buf, prtlen);
 	}
 	else if (strcmp(key, "t") == 0)
 	{
 		/* Literal; return the escape part adding type cast */
-		F_ExtractOldTo(qp, buf, '}', sizeof(buf));
-		prtlen = snprintf(buf, sizeof(buf), "%s::time", buf);
+		F_ExtractOldTo(qp, buf_small, '}', sizeof(buf_small));
+		prtlen = snprintf(buf, sizeof(buf), "%s::time", buf_small);
 		CVT_APPEND_DATA(qb, buf, prtlen);
 	}
 	else if (strcmp(key, "ts") == 0)
 	{
 		/* Literal; return the escape part adding type cast */
-		F_ExtractOldTo(qp, buf, '}', sizeof(buf));
+		F_ExtractOldTo(qp, buf_small, '}', sizeof(buf_small));
 		if (PG_VERSION_LT(qb->conn, 7.1))
-			prtlen = snprintf(buf, sizeof(buf), "%s::datetime", buf);
+			prtlen = snprintf(buf, sizeof(buf), "%s::datetime", buf_small);
 		else
-			prtlen = snprintf(buf, sizeof(buf), "%s::timestamp", buf);
+			prtlen = snprintf(buf, sizeof(buf), "%s::timestamp", buf_small);
 		CVT_APPEND_DATA(qb, buf, prtlen);
 	}
 	else if (strcmp(key, "oj") == 0) /* {oj syntax support for 7.1 * servers */
