@@ -77,7 +77,11 @@ Int2		sqlTypes[] = {
 	/* SQL_BINARY, -- Commented out because VarBinary is more correct. */
 	SQL_BIT,
 	SQL_CHAR,
+#if (ODBCVER >= 0x0300)
+	SQL_TYPE_DATE,
+#else
 	SQL_DATE,
+#endif /* ODBCVER */
 	SQL_DECIMAL,
 	SQL_DOUBLE,
 	SQL_FLOAT,
@@ -87,8 +91,13 @@ Int2		sqlTypes[] = {
 	SQL_NUMERIC,
 	SQL_REAL,
 	SQL_SMALLINT,
+#if (ODBCVER >= 0x0300)
+	SQL_TYPE_TIME,
+	SQL_TYPE_TIMESTAMP,
+#else
 	SQL_TIME,
 	SQL_TIMESTAMP,
+#endif /* ODBCVER */
 	SQL_TINYINT,
 	SQL_VARBINARY,
 	SQL_VARCHAR,
@@ -443,11 +452,11 @@ pgtype_to_ctype(StatementClass *stmt, Int4 type)
 		case PG_TYPE_BPCHAR:
 		case PG_TYPE_VARCHAR:
 		case PG_TYPE_TEXT:
-			/*
-			 * return conn->unicode ? SQL_C_WCHAR : SQL_C_CHAR;
-			 *	The following seems better.
-			 */
+			return conn->unicode ? SQL_C_WCHAR : SQL_C_CHAR;
+			/*	The following seems worse.
+			 *
 			return SQL_C_CHAR;
+			 */
 #endif /* UNICODE_SUPPORT */
 
 		default:
