@@ -81,9 +81,8 @@ PGAPI_RowCount(
 		}
 	}
 
-	SC_set_errornumber(stmt, STMT_SEQUENCE_ERROR);
-	SC_log_error(func, "Bad return value", stmt);
-	return SQL_ERROR;
+	*pcrow = -1;
+	return SQL_SUCCESS;
 }
 
 
